.. _lie-algebras:

===========
Lie Algebra
===========

.. automodule:: sympy.liealgebras

.. autoclass:: sympy.liealgebras.root_system.RootSystem
   :members:

.. autoclass:: sympy.liealgebras.type_a.TypeA
   :members:

.. autoclass:: sympy.liealgebras.type_b.TypeB
   :members:

.. autoclass:: sympy.liealgebras.type_c.TypeC
   :members:

.. autoclass:: sympy.liealgebras.type_d.TypeD
   :members:

.. autoclass:: sympy.liealgebras.type_e.TypeE
   :members:

.. autoclass:: sympy.liealgebras.type_f.TypeF
   :members:

.. autoclass:: sympy.liealgebras.type_g.TypeG
   :members:

.. autoclass:: sympy.liealgebras.weyl_group.WeylGroup
   :members:

.. autoclass:: sympy.liealgebras.cartan_type.CartanType_generator
   :members:

.. autoclass:: sympy.liealgebras.cartan_type.Standard_Cartan
   :members:

.. autofunction:: sympy.liealgebras.dynkin_diagram.DynkinDiagram

.. autofunction:: sympy.liealgebras.cartan_matrix.CartanMatrix
